aboutsummaryrefslogtreecommitdiff
path: root/common/hooks/pre-pkg/99-pkglint.sh
diff options
context:
space:
mode:
Diffstat (limited to 'common/hooks/pre-pkg/99-pkglint.sh')
-rw-r--r--common/hooks/pre-pkg/99-pkglint.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/common/hooks/pre-pkg/99-pkglint.sh b/common/hooks/pre-pkg/99-pkglint.sh
index ada06c485ea..ea73c961ec5 100644
--- a/common/hooks/pre-pkg/99-pkglint.sh
+++ b/common/hooks/pre-pkg/99-pkglint.sh
@@ -21,7 +21,7 @@ hook() {
error=1
fi
done
-
+
for f in var/run usr/local; do
if [ -d ${PKGDESTDIR}/${f} ]; then
msg_red "${pkgver}: /${f} directory is not allowed, remove it!\n"
@@ -54,8 +54,8 @@ hook() {
esac
done
- # Forbid empty packages unless build_style=meta
- if [ "$build_style" != meta -a "$emptypkg" != no ]; then
+ # Forbid empty packages unless build_style=meta or it is 32bit devel package
+ if [ "$build_style" != meta ] && [ "$emptypkg" != no ] && [[ ${pkgname} != *-devel-32bit ]]; then
msg_red "${pkgver}: PKGDESTDIR is empty and build_style != meta\n"
error=1
fi